==> fannypack-2.2.0.tgz: package/es/Container/styled.js <==
var _templateObject = _taggedTemplateLiteralLoose(['\n    margin-right: auto;\n  '], ['\n    margin-right: auto;\n  ']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n    margin-left: auto;\n    margin-right: auto;\n  '], ['\n    margin-left: auto;\n    margin-right: auto;\n  ']),
    _templateObject3 = _taggedTemplateLiteralLoose(['\n    margin-left: auto;\n  '], ['\n    margin-left: auto;\n  ']),
    _templateObject4 = _taggedTemplateLiteralLoose(['\n      & {\n        max-width: ', 'px;\n      }\n    '], ['\n      & {\n        max-width: ', 'px;\n      }\n    ']),
    _templateObject5 = _taggedTemplateLiteralLoose(['\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n  '], ['\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n  ']),
    _templateObject6 = _taggedTemplateLiteralLoose(['\n  ', '\n  ', '\n\n  @media (max-width: ', 'px) {\n    margin: ', ';\n  }\n\n  ', ' /**/\n  ', ';\n\n  ', '\n'], ['\n  ', '\n  ', '\n\n  @media (max-width: ', 'px) {\n    margin: ', ';\n  }\n\n  ', ' /**/\n  ', ';\n\n  ', '\n']),
    _templateObject7 = _taggedTemplateLiteralLoose(['\n      max-width: ', 'px;\n    '], ['\n      max-width: ', 'px;\n    ']),
    _templateObject8 = _taggedTemplateLiteralLoose(['\n      margin: ', ';\n    '], ['\n      margin: ', ';\n    ']);

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import styled, { css } from 'reakit/styled';
import Box from 'reakit/Box';
import { theme } from 'styled-tools';

var alignAttributes = {
  left: css(_templateObject),
  center: css(_templateObject2),
  right: css(_templateObject3)
};

var getResponsiveAttributes = function getResponsiveAttributes(props) {
  var breakpoint = props.breakpoint,
      isFluid = props.isFluid;

  if (isFluid) return;
  if (breakpoint) {
    return css(_templateObject4, theme('layout.' + breakpoint + 'Breakpoint'));
  }
  return css(_templateObject5, function (props) {
    return theme('layout.fullHDBreakpoint')(props) + 128;
  }, theme('layout.widescreenBreakpoint'), function (props) {
    return theme('layout.widescreenBreakpoint')(props) + 128;
  }, theme('layout.desktopBreakpoint'), function (props) {
    return theme('layout.desktopBreakpoint')(props) + 128;
  }, theme('layout.tabletBreakpoint'));
};

export default styled(Box)(_templateObject6, function (props) {
  return !props.isFluid && css(_templateObject7, theme('layout.fullHDBreakpoint'));
}, function (props) {
  return props.isFluid && css(_templateObject8, theme('Container.fluidMargin'));
}, theme('layout.tabletBreakpoint'), theme('Container.tabletMargin'), getResponsiveAttributes, function (props) {
  return !props.isFluid && alignAttributes[props.align];
}, theme('Container.base'));

==> fannypack-2.8.0.tgz: package/es/Container/styled.js <==
var _templateObject = _taggedTemplateLiteralLoose(['\n    margin-right: auto;\n  '], ['\n    margin-right: auto;\n  ']),
    _templateObject2 = _taggedTemplateLiteralLoose(['\n    margin-left: auto;\n    margin-right: auto;\n  '], ['\n    margin-left: auto;\n    margin-right: auto;\n  ']),
    _templateObject3 = _taggedTemplateLiteralLoose(['\n    margin-left: auto;\n  '], ['\n    margin-left: auto;\n  ']),
    _templateObject4 = _taggedTemplateLiteralLoose(['\n      & {\n        max-width: ', 'px;\n      }\n    '], ['\n      & {\n        max-width: ', 'px;\n      }\n    ']),
    _templateObject5 = _taggedTemplateLiteralLoose(['\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n  '], ['\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n\n    @media (max-width: ', 'px) {\n      max-width: ', 'px;\n    }\n  ']),
    _templateObject6 = _taggedTemplateLiteralLoose(['\n  ', '\n  ', '\n\n  @media (max-width: ', 'px) {\n    margin: ', ';\n  }\n\n  ', ' /**/\n  ', ';\n\n  ', '\n'], ['\n  ', '\n  ', '\n\n  @media (max-width: ', 'px) {\n    margin: ', ';\n  }\n\n  ', ' /**/\n  ', ';\n\n  ', '\n']),
    _templateObject7 = _taggedTemplateLiteralLoose(['\n      max-width: ', 'px;\n    '], ['\n      max-width: ', 'px;\n    ']),
    _templateObject8 = _taggedTemplateLiteralLoose(['\n      margin: ', ';\n    '], ['\n      margin: ', ';\n    ']);

function _taggedTemplateLiteralLoose(strings, raw) { strings.raw = raw; return strings; }

import styled, { css } from 'reakit/styled';
import Box from 'reakit/Box';
import { theme } from 'styled-tools';

var alignProperties = {
  left: css(_templateObject),
  center: css(_templateObject2),
  right: css(_templateObject3)
};

var getResponsiveProperties = function getResponsiveProperties(props) {
  var breakpoint = props.breakpoint,
      isFluid = props.isFluid;

  if (isFluid) return;
  if (breakpoint) {
    return css(_templateObject4, theme('layout.' + breakpoint + 'Breakpoint'));
  }
  return css(_templateObject5, function (props) {
    return theme('layout.fullHDBreakpoint')(props) + 128;
  }, theme('layout.widescreenBreakpoint'), function (props) {
    return theme('layout.widescreenBreakpoint')(props) + 128;
  }, theme('layout.desktopBreakpoint'), function (props) {
    return theme('layout.desktopBreakpoint')(props) + 128;
  }, theme('layout.tabletBreakpoint'));
};

export default styled(Box)(_templateObject6, function (props) {
  return !props.isFluid && css(_templateObject7, theme('layout.fullHDBreakpoint'));
}, function (props) {
  return props.isFluid && css(_templateObject8, theme('Container.fluidMargin'));
}, theme('layout.tabletBreakpoint'), theme('Container.tabletMargin'), getResponsiveProperties, function (props) {
  return !props.isFluid && alignProperties[props.align];
}, theme('Container.base'));
